==> ev_framework-3.0.4.tar.gz: lib/_FrameWork/Ev/_Form_onOff.dart <==
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import '../vForm.dart';
import '../vText.dart';
import '../vSystem.dart';

class $$Form_OnOff extends StatefulWidget {
  vForm form;
  var skey;
  var value;
  var onchange;
  TextEditingController controller;
  var label_text;
  var color;

  $$Form_OnOff(Key key,this.skey,this.form,this.value,this.controller,
      {this.label_text,this.color,this.onchange}):super(key:key);

  @override
  _Form_OnOff_State createState() => _Form_OnOff_State();
}

class _Form_OnOff_State extends State<$$Form_OnOff> {
  bool switchvalue;
  vForm form;

  @override
  void initState() {
    // TODO: implement initState
    switchvalue = (widget.value == "1");
    form = widget.form;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    Widget child =  SizedBox(width: 60, height: 30,child:Switch(
         value: switchvalue,
         onChanged: (value) {
           setState(() {
             switchvalue = value ;
             widget.controller.text = value ? "1" : "0";
             if(widget.onchange != null)
               {  widget.onchange(widget.controller.text); }
         }); },
        activeColor: widget.color,
     ));

    if (form.$$_Border_type == 1) {
       return form_type1(child);
    }
    else {
      return form_type2(child);
    }
  }

  Widget form_type1(Widget child) {
    return Container(
      padding: form.$$_Padding,
      child: Column(
        crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
        children: <Widget>[
          (form.$$_Lable_ratio > 0) ?
          Row(
              children: <Widget>[
                Expanded(flex: (form.$$_Lable_ratio * 100).round(), child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size)),
                SizedBox(width: 10),
                Expanded(flex: 100,child: Align(
                  alignment: form.$$_Text_Align == TextAlign.right ? Alignment.centerRight : Alignment.centerLeft,
                  child: Padding(
                    padding: const EdgeInsets.only(bottom: 8.0),
                    child: child,
                  )))
              ]):

          Row(
              children: <Widget>[
                Padding(
                  padding: const EdgeInsets.only(bottom: 8.0),
                  child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                ),
                SizedBox(width: 10),
                Expanded(child: child)
              ]),

          Container(color: form.$$_Border_Color, height: 1,),
        ],
      ),
    );
  }


  Widget form_type2(Widget child) {
      return Container(
      padding: form.$$_Margin,
      child: Column(
        children: <Widget>[
          Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                widget.label_text == "" ? Container() :

                Expanded(
                  flex: (form.$$_Lable_ratio >0) ? (form.$$_Lable_ratio * 100).round() : 0,
                  child: Row(children: [
                    Padding(
                      padding: const EdgeInsets.only(bottom: 8.0),
                      child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                    ),
                    SizedBox(width: 10),
                    ],),
                ),

                Expanded( flex: (form.$$_Lable_ratio >0) ? 100 : 1,
                  child:
                    Column(
                   crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
                   children: [
                    Container(padding: form.$$_Padding, child: child,
                    ),
                  ],
                 ),

                )
              ]),


        ],
      ),
    );
  }

}

==> ev_framework-3.0.10.tar.gz: lib/_FrameWork/Ev/_Form_onOff.dart <==
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import '../vForm.dart';
import '../vText.dart';
import '../vSystem.dart';

class $$Form_OnOff extends StatefulWidget {
  vForm form;
  var skey;
  var value;
  var onchange;
  TextEditingController controller;
  var label_text;
  var color;

  $$Form_OnOff(Key key,this.skey,this.form,this.value,this.controller,
      {this.label_text,this.color,this.onchange}):super(key:key);

  @override
  _Form_OnOff_State createState() => _Form_OnOff_State();
}

class _Form_OnOff_State extends State<$$Form_OnOff> {
  bool switchvalue;
  vForm form;

  @override
  void initState() {
    // TODO: implement initState
    switchvalue = (widget.value == "1");
    form = widget.form;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    Widget child =  SizedBox(width: 60, height: 30,child:Switch(
         value: switchvalue,
         onChanged: (value) {
           setState(() {
             switchvalue = value ;
             widget.controller.text = value ? "1" : "0";
             if(widget.onchange != null)
               {  widget.onchange(widget.controller.text); }
         }); },
        activeColor: widget.color,
     ));

    if (form.$$_Border_type == 1) {
       return form_type1(child);
    }
    else {
      return form_type2(child);
    }
  }

  Widget form_type1(Widget child) {
    return Container(
      padding: form.$$_Padding,
      child: Column(
        crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
        children: <Widget>[
         Padding(padding: form.$$_Padding,child: (form.$$_Lable_ratio > 0) ?
          Row(
              children: <Widget>[
                Expanded(flex: (form.$$_Lable_ratio * 100).round(), child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size)),
                SizedBox(width: 10),
                Expanded(flex: 100,child: Align(
                  alignment: form.$$_Text_Align == TextAlign.right ? Alignment.centerRight : Alignment.centerLeft,
                  child: Padding(
                    padding: const EdgeInsets.only(bottom: 8.0),
                    child: child,
                  )))
              ]):

          Row(
              children: <Widget>[
                Padding(
                  padding: const EdgeInsets.only(bottom: 8.0),
                  child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                ),
                SizedBox(width: 10),
                Expanded(child: child)
              ]),
          ),
          Container(color: form.$$_Border_Color, height: 1,),
        ],
      ),
    );
  }


  Widget form_type2(Widget child) {
      return Container(
      padding: form.$$_Margin,
      child: Column(
        children: <Widget>[
          Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                widget.label_text == "" ? Container() :

                Expanded(
                  flex: (form.$$_Lable_ratio >0) ? (form.$$_Lable_ratio * 100).round() : 0,
                  child: Row(children: [
                    Padding(
                      padding: const EdgeInsets.only(bottom: 8.0),
                      child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                    ),
                    SizedBox(width: 10),
                    ],),
                ),

                Expanded( flex: (form.$$_Lable_ratio >0) ? 100 : 1,
                  child:
                    Column(
                   crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
                   children: [
                    Container(padding: form.$$_Padding, child: child,
                    ),
                  ],
                 ),

                )
              ]),


        ],
      ),
    );
  }

}
